@@ -361,9 +361,9 @@ class HighPerformanceRollingSimilarity:
     """
     
     def __init__(self, 
-                 date_col="Date", 
+                 date_col="Datetime",
                  ticker_col="Ticker", 
-                 ret_col="1D_Close_pct_change",
+                 ret_col="1D_Close_pct_change_x",
                  cache_dir: Optional[str] = None,
                  chunk_size: int = 5000):
         """
@@ -454,7 +454,7 @@ class HighPerformanceRollingSimilarity:
         
         # Set default intervals if not provided
         if intervals is None:
-            intervals = {"Weekly": 5, "Monthly": 21, "Quarterly": 63}
+            intervals = {"Daily": 1, "Weekly": 5, "Monthly": 21, "Quarterly": 63}
         
         # Optimize input data
         df_processed = self._optimize_input_data(df)
